@@ -1,4 +1,4 @@
-/*	$NetBSD: random.c,v 1.5 1997/10/12 01:14:22 lukem Exp $	*/
+/*	$NetBSD: random.c,v 1.6 1999/09/08 21:45:29 jsm Exp $	*/
 
 /*
  * Copyright (c) 1994
@@ -46,7 +46,7 @@ __COPYRIGHT("@(#) Copyright (c) 1994\n\
 #if 0
 static char sccsid[] = "@(#)random.c	8.6 (Berkeley) 6/1/94";
 #else
-__RCSID("$NetBSD: random.c,v 1.5 1997/10/12 01:14:22 lukem Exp $");
+__RCSID("$NetBSD: random.c,v 1.6 1999/09/08 21:45:29 jsm Exp $");
 #endif
 #endif /* not lint */
 
@@ -62,7 +62,7 @@ __RCSID("$NetBSD: random.c,v 1.5 1997/10/12 01:14:22 lukem Exp $");
 #include <limits.h>
 
 int  main __P((int, char **));
-void usage __P((void));
+void usage __P((void)) __attribute__((__noreturn__));
 
 int
 main(argc, argv)
@@ -118,7 +118,7 @@ main(argc, argv)
 
 	/* Compute a random exit status between 0 and denom - 1. */
 	if (random_exit)
-		return ((denom * random()) / LONG_MAX);
+		return ((denom * random()) / RAND_MAX);
 
 	/*
 	 * Act as a filter, randomly choosing lines of the standard input
@@ -133,7 +133,7 @@ main(argc, argv)
 	 * 0 (which has a 1 / denom chance of being true), we select the
 	 * line.
 	 */
-	selected = (int)(denom * random() / LONG_MAX) == 0;
+	selected = (int)(denom * random() / RAND_MAX) == 0;
 	while ((ch = getchar()) != EOF) {
 		if (selected)
 			(void)putchar(ch);
@@ -143,7 +143,7 @@ main(argc, argv)
 				err(2, "stdout");
 
 			/* Now see if the next line is to be printed. */
-			selected = (int)(denom * random() / LONG_MAX) == 0;
+			selected = (int)(denom * random() / RAND_MAX) == 0;
 		}
 	}
 	if (ferror(stdin))
