@@ -48,6 +48,7 @@ __RCSID("$NetBSD: main.c,v 1.6 1997/10/13 21:03:55 christos Exp $");
 #endif /* not lint */
 
 #include "extern.h"
+#include <fcntl.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <string.h>
@@ -57,16 +58,22 @@ int main __P((int, char **));
 /*ARGSUSED*/
 int
 main(argc, argv)
-	int argc __attribute__((unused));
+	int argc __attribute__((__unused__));
 	char **argv;
 {
 	char *p;
 	int i;
+	int fd;
 
 	gid = getgid();
 	egid = getegid();
 	setegid(gid);
 
+	fd = open("/dev/null", O_RDONLY);
+	if (fd < 3)
+		exit(1);
+	close(fd);
+
 	(void) srand(getpid());
 	if ((p = strrchr(*argv, '/')) != NULL)
 		p++;
