@@ -1,4 +1,4 @@
-/*	$NetBSD: capture.c,v 1.4 1997/10/12 21:24:29 christos Exp $	*/
+/*	$NetBSD: capture.c,v 1.5 1999/09/08 21:45:32 jsm Exp $	*/
 
 /*
  * Copyright (c) 1980, 1993
@@ -38,7 +38,7 @@
 #if 0
 static char sccsid[] = "@(#)capture.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: capture.c,v 1.4 1997/10/12 21:24:29 christos Exp $");
+__RCSID("$NetBSD: capture.c,v 1.5 1999/09/08 21:45:32 jsm Exp $");
 #endif
 #endif /* not lint */
 
