@@ -1,4 +1,4 @@
-/*	$NetBSD: getpar.c,v 1.6 1997/10/13 22:12:01 cjs Exp $	*/
+/*	$NetBSD: getpar.c,v 1.7 1999/07/21 13:19:10 hubertf Exp $	*/
 
 /*
  * Copyright (c) 1980, 1993
@@ -38,7 +38,7 @@
 #if 0
 static char sccsid[] = "@(#)getpar.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: getpar.c,v 1.6 1997/10/13 22:12:01 cjs Exp $");
+__RCSID("$NetBSD: getpar.c,v 1.7 1999/07/21 13:19:10 hubertf Exp $");
 #endif
 #endif /* not lint */
 
